base

package
v0.18.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 13, 2025 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Controller

type Controller struct {
	// contains filtered or unexported fields
}

Controller is a controller that handles Base

func NewController

func NewController(
	clusternetClient clusternetclientset.Interface,
	baseInformer appinformers.BaseInformer,
	descInformer appinformers.DescriptionInformer,
	recorder record.EventRecorder,
	syncHandlerFunc SyncHandlerFunc,
) (*Controller, error)

func (*Controller) FindBaseBySubUID added in v0.17.0

func (c *Controller) FindBaseBySubUID(subUid string) ([]*appsapi.Base, error)

func (*Controller) FindBaseByUID added in v0.17.0

func (c *Controller) FindBaseByUID(uid string) (*appsapi.Base, error)

func (*Controller) Run

func (c *Controller) Run(workers int, ctx context.Context)

Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.

type SyncHandlerFunc

type SyncHandlerFunc func(base *appsapi.Base) error

Jump to