Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
// contains filtered or unexported fields
}
Controller is a controller that handles Base
func NewController ¶
func NewController( clusternetClient clusternetclientset.Interface, baseInformer appinformers.BaseInformer, descInformer appinformers.DescriptionInformer, recorder record.EventRecorder, syncHandlerFunc SyncHandlerFunc, ) (*Controller, error)
func (*Controller) FindBaseBySubUID ¶ added in v0.17.0
func (c *Controller) FindBaseBySubUID(subUid string) ([]*appsapi.Base, error)
func (*Controller) FindBaseByUID ¶ added in v0.17.0
func (c *Controller) FindBaseByUID(uid string) (*appsapi.Base, error)
func (*Controller) Run ¶
func (c *Controller) Run(workers int, ctx context.Context)
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
type SyncHandlerFunc ¶
Click to show internal directories.
Click to hide internal directories.